@@ -12,13 +12,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from fuelclient. v1 import environment
-from fuelclient. v1 import node
-from fuelclient. v1 import task
+from fuelclient.v1 import environment
+from fuelclient.v1 import fuelversion
+from fuelclient.v1 import network_group
+from fuelclient.v1 import node
+from fuelclient.v1 import task
 
 
-__all__ = (
-    'environment',
-    'node',
-    'task'
-)
+# Please keeps the list in alphabetical order
+__all__ = ('environment',
+           'fuelversion',
+           'network_group',
+           'node',
+           'task')
